<?php

namespace Bixo\Discussions\Policies;

use Litepie\User\Contracts\UserPolicy;
use Bixo\Discussions\Models\Discussion;

class DiscussionPolicy
{

    /**
     * Determine if the given user can view the discussion.
     *
     * @param UserPolicy $user
     * @param Discussion $discussion
     *
     * @return bool
     */
    public function view(UserPolicy $user, Discussion $discussion)
    {
        if ($user->canDo('discussions.discussion.view') && $user->isAdmin()) {
            return true;
        }

        return $discussion->user_id == user_id() && $discussion->user_type == user_type();
    }

    /**
     * Determine if the given user can create a discussion.
     *
     * @param UserPolicy $user
     * @param Discussion $discussion
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('discussions.discussion.create');
    }

    /**
     * Determine if the given user can update the given discussion.
     *
     * @param UserPolicy $user
     * @param Discussion $discussion
     *
     * @return bool
     */
    public function update(UserPolicy $user, Discussion $discussion)
    {
        if ($user->canDo('discussions.discussion.edit') && $user->isAdmin()) {
            return true;
        }

        return $discussion->user_id == user_id() && $discussion->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given discussion.
     *
     * @param UserPolicy $user
     * @param Discussion $discussion
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Discussion $discussion)
    {
        return $discussion->user_id == user_id() && $discussion->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given discussion.
     *
     * @param UserPolicy $user
     * @param Discussion $discussion
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Discussion $discussion)
    {
        if ($user->canDo('discussions.discussion.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given discussion.
     *
     * @param UserPolicy $user
     * @param Discussion $discussion
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Discussion $discussion)
    {
        if ($user->canDo('discussions.discussion.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
